@@ -4,10 +4,9 @@
 srcdir=`dirname $0`
 test -z "$srcdir" && srcdir=.
 
-REQUIRED_AUTOMAKE_VERSION=1.9
+REQUIRED_AUTOMAKE_VERSION=1.7
 
 PKG_NAME="pango"
-#REQUIRED_M4MACROS=introspection.m4
 
 (test -f $srcdir/configure.in \
   && test -f $srcdir/README \
@@ -18,7 +17,7 @@ PKG_NAME="pango"
 }
 
 which gnome-autogen.sh || {
-    echo "You need to install gnome-common from the GNOME SVN"
+    echo "You need to install gnome-common from the GNOME CVS"
     exit 1
 }
 USE_GNOME2_MACROS=1 USE_COMMON_DOC_BUILD=yes . gnome-autogen.sh
